@@ -5,15 +5,15 @@ test_that("ebirdnotable works correctly", {
   
   out <- ebirdnotable(lat=42, lng=-70, max = 40)
   expect_is(out, "data.frame")
-  expect_equal(dim(out), c(40,11))
+  expect_equal(dim(out), c(40,12))
   expect_is(out$comName, "character")
   expect_is(out$howMany, "integer")
 
-  expect_equal(ncol(ebirdnotable(region='US-OH', regtype='subnational1')), 11)
+  expect_equal(NCOL(ebirdnotable(region='US-OH', regtype='subnational1')), 12)
   
   simpler <- ebirdnotable(lat=42, lng=-70, max = 40, simple = TRUE)
 #   lesssimpler <- ebirdnotable(lat=42, lng=-70, max = 40, simple = FALSE)
-  expect_equal(dim(simpler), c(40,11))
+  expect_equal(dim(simpler), c(40,12))
 #   expect_equal(dim(lesssimpler), c(40,24))
   
   expect_gt(
